@@ -1,18 +1,17 @@
 """Tools for LD matrix and fine-mapping."""
 
+import logging
 import shutil
 import sys
 from typing import Optional, Union
 
-from easyfinemap.logger import logger
-
 
 class Tools:
     """check if tools are installed and return their path."""
-    def __init__(self, log_level: str = "WARNING"):
+
+    def __init__(self):
         """Initialize."""
-        self.logger = logger
-        self.logger.setLevel(log_level)
+        self.logger = logging.getLogger("Tools")
 
     def _check_tool(self, tool: str) -> Optional[str]:
         """
@@ -45,7 +44,22 @@ class Tools:
         """Check if bcftools is installed."""
         return self._check_tool("bcftools")
 
+    @property
+    def gcta(self):
+        """Check if gcta is installed."""
+        return self._check_tool("gcta64")
 
+    @property
+    def finemap(self):
+        """Check if finemap is installed."""
+        return self._check_tool("finemap")
 
+    @property
+    def paintor(self):
+        """Check if paintor is installed."""
+        return self._check_tool("PAINTOR")
 
-
+    @property
+    def caviarbf(self):
+        """Check if caviarbf is installed."""
+        return self._check_tool("caviarbf")
